BOOST_PP_ARRAY_REPLACE_D

The BOOST_PP_ARRAY_REPLACE_D macro replaces an element in an array. It reenters BOOST_PP_WHILE with maximum efficiency.

#### Usage

BOOST_PP_ARRAY_REPLACE_D(d, array, i, elem)

#### Arguments

d
  The next available BOOST_PP_WHILE iteration.
array
  An array to replace an element in.
i
  The zero-based position in array of the element to be replaced. Valid values range from 0 to BOOST_PP_ARRAY_SIZE(array) - 1.
elem
  The replacement element.

#### See Also

- BOOST_PP_ARRAY_REPLACE

#### Requirements

Header: <boost/preprocessor/array/replace.hpp>

© Copyright Housemarque Oy 2002 © Copyright Paul Mensonides 2002

Distributed under the Boost Software License, Version 1.0. (See accompanying file LICENSE_1_0.txt or copy at www.boost.org/LICENSE_1_0.txt)